class ASOR:
	RESET = "\x1b[0m"
	DYELLOW = "\x1b[2;33;40m"
	DRED = "\x1b[2;31;40m"

async def info(text: str):
	print(f"{ASOR.DYELLOW}INFO: {text}{ASOR.RESET}")

async def error(err: str):
	print(f"{ASOR.DRED}ERR:  {err}{ASOR.RESET}")



import aiohttp
import time

async def req_async(url: str):
    async with aiohttp.ClientSession() as sess:
        async with sess.get(url) as resp:
            return await resp.json()

async def time_took(st: float) -> float:
    time_taken = (time.time_ns() - st) / 1000 # nanos -> micros
    time_str = (f'{time_taken:.2f}μs' if time_taken < 1000
        else f'{time_taken / 1000:.2f}ms')

    return time_str